@@ -15,9 +15,9 @@ from botoy.exceptions import InvalidConfigError
 
 DEFAULT_HOST = "http://127.0.0.1"
 DEFAULT_PORT = 8888
-DEFAULT_GROUP_BLACKLIST = []
-DEFAULT_FRIEND_BLACKLIST = []
-DEFAULT_BLOCK_UESRS = []
+DEFAULT_GROUP_BLACKLIST: List[int] = []
+DEFAULT_FRIEND_BLACKLIST: List[int] = []
+DEFAULT_BLOCK_UESRS: List[int] = []
 DEFAULT_WEBHOOK = False
 DEFAULT_WEBHOOK_POST_URL = "http://127.0.0.1:5000"
 DEFAULT_WEBHOOK_TIMEOUT = 20
