@@ -7,14 +7,14 @@ from pathlib import Path
 
 def file_to_base64(path):
     """获取文件base64编码"""
-    with open(path, 'rb') as f:
+    with open(path, "rb") as f:
         content = f.read()
     return base64.b64encode(content).decode()
 
 
 def check_schema(url: str) -> str:
-    url = url.strip('/')
-    if not re.findall(r'(http://|https://)', url):
+    url = url.strip("/")
+    if not re.findall(r"(http://|https://)", url):
         return "http://" + url
     return url
 
@@ -25,24 +25,24 @@ def get_cache_dir(dir_name: str) -> Path:
     :return: A Path object of the cache directory
     """
     # 确定主缓存目录
-    for i in os.listdir(Path('.')):
-        if i in ['botoy.json', 'REMOVED_PLUGINS', 'bot.py', 'plugins']:
-            main_dir = Path('.')
+    for i in os.listdir(Path(".")):
+        if i in ["botoy.json", "REMOVED_PLUGINS", "bot.py", "plugins"]:
+            main_dir = Path(".")
             break
     else:
         cf = inspect.currentframe()
         bf = cf.f_back
-        file = bf.f_globals['__file__']
+        file = bf.f_globals["__file__"]
         dir_ = Path(file).absolute()
-        while 'plugins' in str(dir_):
+        while "plugins" in str(dir_):
             dir_ = dir_.parent
-            if dir_.name == 'plugins':
+            if dir_.name == "plugins":
                 main_dir = dir_.parent
                 break
         else:
-            main_dir = Path('.')
+            main_dir = Path(".")
 
-    cache_dir = main_dir / 'botoy-cache'
+    cache_dir = main_dir / "botoy-cache"
     if not cache_dir.exists():
         cache_dir.mkdir()
 
